//
// C++ Interface: CProjectEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CPROJECTEDITDLG_H
#define CPROJECTEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_projectdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CProjectEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CProjectEditDlg(QWidget * parent = 0);
    QString getfile();
    QString getpath();
    ~CProjectEditDlg();



public slots:
    virtual void slotGetData();
    virtual void slotEditData();
    virtual void slotEditText(const QString & text);
    virtual void slotEditPath();
    virtual void slotEditPathDir();
 
private slots:
 
protected:
    Ui::ProjectEditDlg ui;    
    FolderListItem *point;

    
private:
//    QWidget *myParent;
    QString tmppath;
    int state;
};
#endif
